from setuptools import setup, find_packages

setup(
    name="cr_arch",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        # NEED TO ADD DEPENDENCIES!
    ],
    author="Shiyang Lai",
    author_email="shiyanglai@uchicago.edu",
    description="A package for implementing multi-pipeline neural network architecture for conversation recognition."
)